pub mod headers {
    use std::borrow::Cow;

    pub trait HeadersExt<'a> {
        fn has_any(&self, headers: impl IntoIterator<Item = &'_ str>) -> bool {
            headers.into_iter().any(|h| self.has(h))
        }
        fn has_all(&self, headers: impl IntoIterator<Item = &'_ str>) -> bool {
            headers.into_iter().all(|h| self.has(h))
        }
        fn has(&self, header: &str) -> bool;
        fn get(&self, header: &str) -> Option<Cow<'a, str>>;
    }

    impl<'a> HeadersExt<'a> for &mut [httparse::Header<'a>] {
        fn has(&self, header: &str) -> bool {
            self.iter().any(|h| h.name.eq_ignore_ascii_case(header))
        }

        fn get(&self, header: &str) -> Option<Cow<'a, str>> {
            self.iter()
                .find(|h| h.name.eq_ignore_ascii_case(header))
                .map(|h| String::from_utf8_lossy(h.value))
        }
    }
}
